@@ -3,11 +3,8 @@
 // Use is subject to license terms.
 //
 
-use anyhow::Context;
-
 use super::*;
 
-#[async_trait::async_trait]
 pub(super) trait KubeconfigExt {
     fn default_context(&self) -> Option<&str>;
     // fn validate_contexts(&self, names: Vec<String>) -> anyhow::Result<Vec<String>>;
@@ -15,10 +12,8 @@ pub(super) trait KubeconfigExt {
     fn current_context(&self) -> Option<&str>;
     fn all_contexts(&self) -> Vec<&str>;
     fn current_cluster_name(&self) -> Option<v0::ClusterName>;
-    async fn context_config(&self, context: &str) -> anyhow::Result<Config>;
 }
 
-#[async_trait::async_trait]
 impl KubeconfigExt for Kubeconfig {
     fn default_context(&self) -> Option<&str> {
         self.current_context
@@ -60,16 +55,4 @@ impl KubeconfigExt for Kubeconfig {
     fn current_cluster_name(&self) -> Option<v0::ClusterName> {
         self.default_context().map(normalize_name)
     }
-
-    async fn context_config(&self, context: &str) -> anyhow::Result<Config> {
-        let context = context.to_string();
-        let options = KubeConfigOptions {
-            context: Some(context),
-            ..KubeConfigOptions::default()
-        };
-        let kubeconfig = self.clone();
-        Config::from_custom_kubeconfig(kubeconfig, &options)
-            .await
-            .context("Loading context from kubeconfig")
-    }
 }
