@@ -21,18 +21,17 @@ impl Show for Node {
             .map(|condition| condition.type_.as_str())
             .unwrap_or_default();
 
-        self.namespace()
-            .map(|ns| {
+        self.namespace().map_or_else(
+            || fmt::format(format_args!("Node: {} status: {}", self.name(), condition)),
+            |ns| {
                 fmt::format(format_args!(
                     "Node: {} ({}) status: {}",
                     self.name(),
                     ns,
                     condition
                 ))
-            })
-            .unwrap_or_else(|| {
-                fmt::format(format_args!("Node: {} status: {}", self.name(), condition))
-            })
+            },
+        )
     }
 }
 
@@ -43,16 +42,17 @@ impl Show for Pod {
             .as_ref()
             .and_then(|status| status.phase.as_deref())
             .unwrap_or_default();
-        self.namespace()
-            .map(|ns| {
+        self.namespace().map_or_else(
+            || fmt::format(format_args!("Pod: {} status: {}", self.name(), status)),
+            |ns| {
                 fmt::format(format_args!(
                     "Pod: {} ({}) status: {}",
                     self.name(),
                     ns,
                     status
                 ))
-            })
-            .unwrap_or_else(|| fmt::format(format_args!("Pod: {} status: {}", self.name(), status)))
+            },
+        )
     }
 }
 
